@@ -8,11 +8,11 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-import pyutilib.plugin.core
-pyutilib.plugin.core.PluginGlobals.push_env( 'coopr.opt' )
+import pyutilib.component.core
+pyutilib.component.core.PluginGlobals.push_env( 'coopr.opt' )
 
 import glpsol
 import pico
 import pyomo
 
-pyutilib.plugin.core.PluginGlobals.pop_env()
+pyutilib.component.core.PluginGlobals.pop_env()
