@@ -8,13 +8,14 @@
 #  For more information, see the Coopr README.txt file.
 #  _________________________________________________________________________
 
-import pyutilib.plugin.core
-pyutilib.plugin.core.PluginGlobals.push_env( 'coopr.opt' )
+import pyutilib.component.core
+pyutilib.component.core.PluginGlobals.push_env( 'coopr.opt' )
 
 from PICO import PICO, MockPICO
 from CBC import CBC, MockCBC
 from GLPK import GLPK, MockGLPK
 from CPLEX import CPLEX, MockCPLEX
+from ASL import ASL, MockASL
 #from NLWRITE import NLWRITE
 
-pyutilib.plugin.core.PluginGlobals.pop_env()
+pyutilib.component.core.PluginGlobals.pop_env()
