@@ -12,7 +12,7 @@
 __all__ = []
 
 import pyutilib.misc
-import pyutilib.plugin.core
+import pyutilib.component.core
 from coopr.opt.parallel.manager import *
 from coopr.opt.parallel.solver import *
 from coopr.opt.results import SolverResults
